import random


class Bucket(object):

    def __init__(self, size=4):
        self.size = size
        self.bucket = []

    def __repr__(self):
        return '<Bucket: ' + str(self.bucket) + '>'

    def __contains__(self, item):
        return item in self.bucket

    def __len__(self):
        return len(self.bucket)

    def insert(self, item):
        """
        Insert a fingerprint into the bucket
        :param item:
        :return:
        """
        if not self.is_full():
            self.bucket.append(item)
            return True
        return False

    def delete(self, item):
        """
        Delete a fingerprint from the bucket.
        :param item:
        :return:
        """
        try:
            del self.bucket[self.bucket.index(item)]
            return True
        except ValueError:
            return False

    def is_full(self):
        return len(self.bucket) == self.size

    def swap(self, item):
        """
        Swap fingerprint with a random entry stored in the bucket and return
        the swapped fingerprint
        :param item:
        :return:
        """
        index = random.choice(range(len(self.bucket)))
        swapped_item = self.bucket[index]
        self.bucket[index] = item
        return swapped_item



#!/usr/bin/env python3

from cuckoopy import __version__, __author__
try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

with open('README.rst') as f:
        readme = f.read()

setup(name='cuckoopy',
      version=__version__,
      description='Cuckoo Filter implementation in Python',
      long_description=readme,
      author=__author__,
      author_email='rajathagasthya@gmail.com',
      url='https://github.com/rajathagasthya/cuckoopy',
      license='MIT',
      packages=['cuckoopy'],
      install_requires=[],
      classifiers=[
          'Development Status :: 3 - Alpha',
          'Intended Audience :: Developers',
          'Natural Language :: English',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6'
      ],
)
